# allink-core
This repository contains core functionality for components used at allink AG.


## Documentation
We maintain documentation for several versions of the project. Key versions is:

[v2.0.x](http://allink-core.readthedocs.io/en/v2.0.x/)
